Index: content/public/browser/devtools_frontend_host.h |
diff --git a/content/public/browser/devtools_frontend_host.h b/content/public/browser/devtools_frontend_host.h |
index 24c50f51e07b1e61ac22fb15c40db11c36d65f22..d1b01fe537a1c5d2f196483130520f5ee8c6d665 100644 |
--- a/content/public/browser/devtools_frontend_host.h |
+++ b/content/public/browser/devtools_frontend_host.h |
@@ -11,7 +11,7 @@ |
namespace content { |
-class RenderViewHost; |
+class WebContents; |
// This class dispatches messages between DevTools frontend and Delegate |
// which is implemented by the embedder. |
@@ -35,10 +35,11 @@ class DevToolsFrontendHost { |
const std::string& message) = 0; |
}; |
// Creates a new DevToolsFrontendHost for RenderViewHost where DevTools |
// frontend is loaded. |
CONTENT_EXPORT static DevToolsFrontendHost* Create( |
- RenderViewHost* frontend_rvh, Delegate* delegate); |
+ WebContents* frontend_web_contents, |
+ Delegate* delegate); |
CONTENT_EXPORT virtual ~DevToolsFrontendHost() {} |
}; |
@@ -35,10 +35,11 @@ class DevToolsFrontendHost { |
const std::string& message) = 0; |
}; |
- // Creates a new DevToolsFrontendHost for RenderViewHost where DevTools |
+ // Creates a new DevToolsFrontendHost for WebContents where DevTools |
// frontend is loaded. |
CONTENT_EXPORT static DevToolsFrontendHost* Create( |